import cheerio from "cheerio";
import { isTypeReferenceNode } from "typescript";

export namespace Template {
    export async function check(html: string) {
        try {
            const $ = cheerio.load(html);

            return false;
        } catch (error) {
            console.error(`Error occured during stock check!`);
            return false;
        }
    }
}

export namespace LDJsonParser {
    export async function check(html: string) {
        try {
            const snippets: Array<string> = [];
            const $ = cheerio.load(html);
            $('script[type="application/ld+json"]').each((index, element) => {
                snippets.push($(element).html());
                
            });
            
            for (const snippet of snippets) {
                try {
                    let json = JSON.parse(snippet);
    
                    if (json["@type"]) {
                        if (json["@type"].includes("Product")) {
                            if (Array.isArray(json["offers"])) {
                                for (let index in json["offers"]) {
                                    if (json["offers"][index]["availability"].includes("InStock")) {
                                        return true;
                                    }
                                }
                            } else {
                                if (json["offers"]["availability"].includes("InStock")) {
                                    return true;
                                }
                            }
                        }
                    }
                } catch (error) {
                    console.log(error);
                    continue;
                }
            }

            return false;
        } catch (error) {
            console.log(error);
            console.error(`Error occured during stock check!`);
            return false;
        }
    }
}

export namespace CoolBlue {
    export async function check(html: string) {
        try {
            const snippets: Array<string> = [];
            const $ = cheerio.load(html);
            $('script[type="application/ld+json"]').each((index, element) => {
                snippets.push($(element).html());
            });
            
            for (const snippet of snippets) {
                try {
                    if (snippet.includes(`"@type": "Product"`)) {
                        if (snippet.includes(`"availability": "https://schema.org/InStock"`)) {
                            return true;
                        }
                    }
                } catch (error) {
                    console.log(error);
                    continue;
                }
            }

            return false;
        } catch (error) {
            console.log(error);
            console.error(`Error occured during stock check!`);
            return false;
        }
    }
}


export namespace Dobey {
    export async function check(html: string) {
        try {
            const $ = cheerio.load(html);
            if ($("#product_view #stock_indicator").hasClass("stock_green")) {
                return true;
            } else {
                return false;
            }
        } catch (error) {
            console.log(error);
            console.error(`Error occured during stock check!`);
            return false;
        }
    }
}

export namespace EP {
    export async function check(html: string) {
        try {
            const $ = cheerio.load(html);
            if ($(".product__info--stock_row").first().find("p").hasClass("is-green")) {
                return true;
            } else {
                return false;
            }
        } catch (error) {
            console.log(error);
            console.error(`Error occured during stock check!`);
            return false;
        }
    }
}


export namespace Macrovet {
    export async function check(html: string) {
        try {
            const $ = cheerio.load(html);
            if ($(".product-detail-price-container .product-available-stock").first().text().includes("0 in voorraad")) {
                return false;
            } else {
                return true;
            }
        } catch (error) {
            console.log(error);
            console.error(`Error occured during stock check!`);
            return false;
        }
    }
}
